# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class HeartBeatRule(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HeartBeatRule - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'sender_id': 'str',
            'heart_beat_timeout_in_minutes': 'int',
            'enabled': 'bool',
            'in_alarm': 'bool',
            'notification_users': 'list[User]',
            'alert_types': 'list[str]',
            'rule_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'sender_id': 'senderId',
            'heart_beat_timeout_in_minutes': 'heartBeatTimeoutInMinutes',
            'enabled': 'enabled',
            'in_alarm': 'inAlarm',
            'notification_users': 'notificationUsers',
            'alert_types': 'alertTypes',
            'rule_type': 'ruleType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._sender_id = None
        self._heart_beat_timeout_in_minutes = None
        self._enabled = False
        self._in_alarm = False
        self._notification_users = None
        self._alert_types = None
        self._rule_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this HeartBeatRule.
        The globally unique identifier for the object.

        :return: The id of this HeartBeatRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HeartBeatRule.
        The globally unique identifier for the object.

        :param id: The id of this HeartBeatRule.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this HeartBeatRule.
        Name of the rule

        :return: The name of this HeartBeatRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HeartBeatRule.
        Name of the rule

        :param name: The name of this HeartBeatRule.
        :type: str
        """
        
        self._name = name

    @property
    def sender_id(self):
        """
        Gets the sender_id of this HeartBeatRule.
        The value that identifies the sender of the heartbeat.

        :return: The sender_id of this HeartBeatRule.
        :rtype: str
        """
        return self._sender_id

    @sender_id.setter
    def sender_id(self, sender_id):
        """
        Sets the sender_id of this HeartBeatRule.
        The value that identifies the sender of the heartbeat.

        :param sender_id: The sender_id of this HeartBeatRule.
        :type: str
        """
        
        self._sender_id = sender_id

    @property
    def heart_beat_timeout_in_minutes(self):
        """
        Gets the heart_beat_timeout_in_minutes of this HeartBeatRule.
        The number of minutes to wait before alerting missing heartbeats.

        :return: The heart_beat_timeout_in_minutes of this HeartBeatRule.
        :rtype: int
        """
        return self._heart_beat_timeout_in_minutes

    @heart_beat_timeout_in_minutes.setter
    def heart_beat_timeout_in_minutes(self, heart_beat_timeout_in_minutes):
        """
        Sets the heart_beat_timeout_in_minutes of this HeartBeatRule.
        The number of minutes to wait before alerting missing heartbeats.

        :param heart_beat_timeout_in_minutes: The heart_beat_timeout_in_minutes of this HeartBeatRule.
        :type: int
        """
        
        self._heart_beat_timeout_in_minutes = heart_beat_timeout_in_minutes

    @property
    def enabled(self):
        """
        Gets the enabled of this HeartBeatRule.
        Indicates if the rule is enabled.

        :return: The enabled of this HeartBeatRule.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this HeartBeatRule.
        Indicates if the rule is enabled.

        :param enabled: The enabled of this HeartBeatRule.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def in_alarm(self):
        """
        Gets the in_alarm of this HeartBeatRule.
        Indicates if the rule is in alarm state.

        :return: The in_alarm of this HeartBeatRule.
        :rtype: bool
        """
        return self._in_alarm

    @in_alarm.setter
    def in_alarm(self, in_alarm):
        """
        Sets the in_alarm of this HeartBeatRule.
        Indicates if the rule is in alarm state.

        :param in_alarm: The in_alarm of this HeartBeatRule.
        :type: bool
        """
        
        self._in_alarm = in_alarm

    @property
    def notification_users(self):
        """
        Gets the notification_users of this HeartBeatRule.
        The ids of users who will be notified of alarm state change.

        :return: The notification_users of this HeartBeatRule.
        :rtype: list[User]
        """
        return self._notification_users

    @notification_users.setter
    def notification_users(self, notification_users):
        """
        Sets the notification_users of this HeartBeatRule.
        The ids of users who will be notified of alarm state change.

        :param notification_users: The notification_users of this HeartBeatRule.
        :type: list[User]
        """
        
        self._notification_users = notification_users

    @property
    def alert_types(self):
        """
        Gets the alert_types of this HeartBeatRule.
        A collection of notification methods. = ['SMS', 'DEVICE', 'EMAIL'].

        :return: The alert_types of this HeartBeatRule.
        :rtype: list[str]
        """
        return self._alert_types

    @alert_types.setter
    def alert_types(self, alert_types):
        """
        Sets the alert_types of this HeartBeatRule.
        A collection of notification methods. = ['SMS', 'DEVICE', 'EMAIL'].

        :param alert_types: The alert_types of this HeartBeatRule.
        :type: list[str]
        """
        
        self._alert_types = alert_types

    @property
    def rule_type(self):
        """
        Gets the rule_type of this HeartBeatRule.
        The type of system the will be generating the heartbeat.

        :return: The rule_type of this HeartBeatRule.
        :rtype: str
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """
        Sets the rule_type of this HeartBeatRule.
        The type of system the will be generating the heartbeat.

        :param rule_type: The rule_type of this HeartBeatRule.
        :type: str
        """
        allowed_values = ["EDGE"]
        if rule_type not in allowed_values:
            raise ValueError(
                "Invalid value for `rule_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._rule_type = rule_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this HeartBeatRule.
        The URI for this object

        :return: The self_uri of this HeartBeatRule.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this HeartBeatRule.
        The URI for this object

        :param self_uri: The self_uri of this HeartBeatRule.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

